@@ -90,6 +90,7 @@ a `<user>` is represented by his ID
             Some(true) => out.push_str("\n**moderation**: enabled"),
             Some(false) | None => out.push_str("\n**moderation**: disabled"),
         }
+        out.push_str(val::VERSION);
         out
     }
 }
@@ -160,4 +161,68 @@ pub mod moderation {
             }
         }
     }
+    
+    /// kick a user
+    ///
+    /// # Arguments
+    ///
+    /// * `msg`: the message to parse
+    /// * `conf`: the configuration to use
+    /// * `ctx`: the context to use for some checking things
+    ///
+    /// # Return
+    ///
+    /// The message to send as a String
+    pub async fn kick(msg: Message, conf: Config, ctx: &Context) -> String {
+        let context: Context = ctx.clone();
+        let gid: GuildId = match msg.guild_id {
+            Some(n) => n,
+            None => {
+                return String::from("you need to send this message in a server");
+            }
+        };
+        let modrole: RoleId = match conf.moderating {
+            Some(n) => RoleId(n.modrole),
+            None => {
+                return String::from("Modrole not specified in the config file");
+            }
+        };
+        match msg.author.has_role(&context, gid, modrole).await {
+            Ok(true) => {
+                if msg.mentions.len() != 1 {
+                    return String::from("you need to mention the person you want to kick");
+                } else {
+                    let user: &User = &msg.mentions[0];
+                    let parts: Vec<&str> = msg.content.as_str().split_whitespace().collect();
+                    if parts.len() > 2 {
+                        let reason_vec: Vec<&str> = parts[2..].to_vec();
+                        let mut reason: String = String::new();
+                        for i in reason_vec {
+                            reason = format!("{} {}", reason, i);
+                        }
+                        reason = reason[1..].to_string();
+                        if let Err(e) = gid.kick(&context, user.id).await {
+                            println!("failed to kick user: {:?}", e);
+                            return format!("failed to kick user: {}", e);
+                        }
+                        return format!("{} has been kicked. Reason: {}", user.name, reason);
+                    } else {
+                        if let Err(e) = gid.kick(&context, user.id).await {
+                            println!("failed to kick user: {:?}", e);
+                            return format!("failed to kick user: {}", e);
+                        }
+                        return format!("{} has been kicked", user.name);
+                    }
+                }
+            }
+
+            Ok(false) => {
+                return String::from("you need to be a moderator to execute this command");
+            }
+
+            Err(e) => {
+                return format!("Error while checking permissions: `{}`", e);
+            }
+        }
+    }
 }
